@@ -1,6 +1,6 @@
 import {EditorState} from "@codemirror/state"
 import {CompletionContext, CompletionResult, CompletionSource} from "@codemirror/autocomplete"
-import {schemaCompletionSource, PostgreSQL, MySQL, SQLConfig} from "@codemirror/lang-sql"
+import {schemaCompletionSource, PostgreSQL, MySQL, SQLConfig, SQLDialect} from "@codemirror/lang-sql"
 import ist from "ist"
 
 function get(doc: string, conf: SQLConfig & {explicit?: boolean} = {}) {
@@ -162,6 +162,15 @@ describe("SQL completion", () => {
         '`b c`, `b-c`, bup')
   })
 
+  it("adds identifiers for upper case completions", () => {
+    ist(str(get("foo.c|", {schema: {foo: ["Column", "cell"]}, dialect: PostgreSQL})),
+        '"Column", cell')
+
+    const customDialect = SQLDialect.define({...PostgreSQL.spec, caseInsensitiveIdentifiers: true})
+    ist(str(get("foo.c|", {schema: {foo: ["Column", "cell"]}, dialect: customDialect})),
+        'Column, cell')
+  })
+
   it("supports nesting more than two deep", () => {
     let s = {schema: {"one.two.three": ["four"]}}
     ist(str(get("o|", s)), "one")
